""" Example of wrapping a C function that takes C double arrays as input using
    the Numpy declarations from Cython """

# import both numpy and the Cython declarations for numpy
import numpy as np
cimport numpy as np

# if you want to use the Numpy-C-API from Cython
# (not strictly necessary for this example)
np.import_array()

# cdefine the signature of our c function
cdef extern from "cos_doubles.h":
  void cos_doubles (double* in_array, double* out_array, int size)

# create the wrapper code, with numpy type annotations
def cos_doubles_func(np.ndarray[double, ndim=1, mode="c"] in_array not None, np.ndarray[double, ndim=1, mode="c"] out_array not None):
  """ Careful with the types. double double """

  cos_doubles(<double*> np.PyArray_DATA(in_array), <double*> np.PyArray_DATA(out_array), in_array.shape[0])




from distutils.core import setup, Extension
import numpy
from Cython.Distutils import build_ext

setup(
  cmdclass={'build_ext': build_ext}, 
  ext_modules=[Extension("cos_doubles",
               sources=["_cos_doubles.pyx", "cos_doubles.c"], 
               include_dirs=[numpy.get_include()])],
)

